==> cryptocom-exchange-0.7.tar.gz: cryptocom-exchange-0.7/src/cryptocom/exchange/pairs.py <==
from .structs import Pair

NEO_BTC = Pair("NEO_BTC", 6, 3)
ADA_BTC = Pair("ADA_BTC", 8, 0)
ICX_BTC = Pair("ICX_BTC", 8, 1)
ETH_CRO = Pair("ETH_CRO", 2, 3)
VET_CRO = Pair("VET_CRO", 4, 0)
XRP_BTC = Pair("XRP_BTC", 8, 0)
BCH_BTC = Pair("BCH_BTC", 6, 3)
OMG_BTC = Pair("OMG_BTC", 6, 4)
CRO_BTC = Pair("CRO_BTC", 8, 2)
LTC_CRO = Pair("LTC_CRO", 2, 2)
KNC_CRO = Pair("KNC_CRO", 3, 2)
ENJ_CRO = Pair("ENJ_CRO", 3, 2)
XTZ_BTC = Pair("XTZ_BTC", 7, 2)
XLM_CRO = Pair("XLM_CRO", 3, 2)
EOS_CRO = Pair("EOS_CRO", 3, 2)
ETH_BTC = Pair("ETH_BTC", 6, 3)
DAI_CRO = Pair("DAI_CRO", 3, 3)
MKR_CRO = Pair("MKR_CRO", 2, 3)
BAT_CRO = Pair("BAT_CRO", 3, 2)
VET_BTC = Pair("VET_BTC", 8, 0)
NEO_CRO = Pair("NEO_CRO", 3, 2)
ADA_CRO = Pair("ADA_CRO", 3, 2)
ICX_CRO = Pair("ICX_CRO", 2, 0)
XRP_CRO = Pair("XRP_CRO", 2, 0)
BCH_CRO = Pair("BCH_CRO", 2, 3)
OMG_CRO = Pair("OMG_CRO", 3, 2)
LTC_BTC = Pair("LTC_BTC", 6, 2)
XLM_BTC = Pair("XLM_BTC", 8, 0)
UNI_CRO = Pair("UNI_CRO", 3, 2)
EOS_BTC = Pair("EOS_BTC", 7, 2)
YFI_CRO = Pair("YFI_CRO", 2, 4)
XTZ_CRO = Pair("XTZ_CRO", 3, 2)
WBTC_BTC = Pair("WBTC_BTC", 4, 4)
LINK_CRO = Pair("LINK_CRO", 2, 2)
BTC_USDT = Pair("BTC_USDT", 2, 6)
OMG_USDT = Pair("OMG_USDT", 4, 4)
NEO_USDT = Pair("NEO_USDT", 3, 4)
VET_USDT = Pair("VET_USDT", 6, 0)
YFI_USDT = Pair("YFI_USDT", 2, 6)
MANA_BTC = Pair("MANA_BTC", 8, 1)
ATOM_BTC = Pair("ATOM_BTC", 7, 2)
EOS_USDT = Pair("EOS_USDT", 4, 2)
ALGO_BTC = Pair("ALGO_BTC", 8, 2)
KNC_USDT = Pair("KNC_USDT", 3, 3)
AAVE_CRO = Pair("AAVE_CRO", 2, 3)
XLM_USDT = Pair("XLM_USDT", 5, 1)
CELR_CRO = Pair("CELR_CRO", 4, 1)
LINK_BTC = Pair("LINK_BTC", 7, 2)
ENJ_USDT = Pair("ENJ_USDT", 5, 1)
XTZ_USDT = Pair("XTZ_USDT", 4, 2)
QTUM_CRO = Pair("QTUM_CRO", 3, 2)
COMP_CRO = Pair("COMP_CRO", 2, 3)
MKR_USDT = Pair("MKR_USDT", 2, 6)
EGLD_CRO = Pair("EGLD_CRO", 3, 2)
PAXG_CRO = Pair("PAXG_CRO", 2, 4)
DAI_USDT = Pair("DAI_USDT", 4, 3)
LTC_USDT = Pair("LTC_USDT", 2, 5)
ETH_USDT = Pair("ETH_USDT", 2, 5)
BAND_CRO = Pair("BAND_CRO", 3, 2)
XRP_USDT = Pair("XRP_USDT", 5, 1)
BAT_USDT = Pair("BAT_USDT", 4, 2)
CRO_USDC = Pair("CRO_USDC", 4, 3)
UNI_USDT = Pair("UNI_USDT", 4, 4)
BCH_USDT = Pair("BCH_USDT", 2, 5)
MANA_CRO = Pair("MANA_CRO", 3, 2)
CRO_USDT = Pair("CRO_USDT", 4, 3)
ICX_USDT = Pair("ICX_USDT", 4, 2)
ADA_USDT = Pair("ADA_USDT", 5, 1)
ATOM_CRO = Pair("ATOM_CRO", 2, 2)
ALGO_CRO = Pair("ALGO_CRO", 3, 2)
MANA_USDT = Pair("MANA_USDT", 4, 2)
LINK_USDT = Pair("LINK_USDT", 3, 2)
ATOM_USDT = Pair("ATOM_USDT", 3, 2)
COMP_USDT = Pair("COMP_USDT", 2, 5)
PAXG_USDT = Pair("PAXG_USDT", 2, 5)
USDC_USDT = Pair("USDC_USDT", 4, 2)
ALGO_USDT = Pair("ALGO_USDT", 4, 2)
AAVE_USDT = Pair("AAVE_USDT", 3, 4)
CELR_USDT = Pair("CELR_USDT", 5, 1)
EGLD_USDT = Pair("EGLD_USDT", 4, 3)
WBTC_USDT = Pair("WBTC_USDT", 2, 6)
QTUM_USDT = Pair("QTUM_USDT", 4, 4)
BAND_USDT = Pair("BAND_USDT", 4, 2)


def all():
    return [
        value for name, value in globals().items()
        if isinstance(value, Pair)
    ]

==> cryptocom-exchange-0.7.3.tar.gz: cryptocom-exchange-0.7.3/src/cryptocom/exchange/pairs.py <==
from .structs import Pair

NEO_BTC = Pair("NEO_BTC", 6, 3)
ADA_BTC = Pair("ADA_BTC", 8, 0)
ICX_BTC = Pair("ICX_BTC", 8, 1)
ETH_CRO = Pair("ETH_CRO", 2, 3)
VET_CRO = Pair("VET_CRO", 4, 0)
XRP_BTC = Pair("XRP_BTC", 8, 0)
BCH_BTC = Pair("BCH_BTC", 6, 3)
OMG_BTC = Pair("OMG_BTC", 6, 4)
CRO_BTC = Pair("CRO_BTC", 8, 2)
LTC_CRO = Pair("LTC_CRO", 2, 2)
KNC_CRO = Pair("KNC_CRO", 3, 2)
ENJ_CRO = Pair("ENJ_CRO", 3, 2)
XTZ_BTC = Pair("XTZ_BTC", 7, 2)
XLM_CRO = Pair("XLM_CRO", 3, 2)
EOS_CRO = Pair("EOS_CRO", 3, 2)
ETH_BTC = Pair("ETH_BTC", 6, 3)
DAI_CRO = Pair("DAI_CRO", 3, 3)
MKR_CRO = Pair("MKR_CRO", 2, 3)
BAT_CRO = Pair("BAT_CRO", 3, 2)
VET_BTC = Pair("VET_BTC", 8, 0)
NEO_CRO = Pair("NEO_CRO", 3, 2)
ADA_CRO = Pair("ADA_CRO", 3, 2)
ICX_CRO = Pair("ICX_CRO", 2, 0)
XRP_CRO = Pair("XRP_CRO", 2, 0)
BCH_CRO = Pair("BCH_CRO", 2, 3)
OMG_CRO = Pair("OMG_CRO", 3, 2)
LTC_BTC = Pair("LTC_BTC", 6, 2)
XLM_BTC = Pair("XLM_BTC", 8, 0)
UNI_CRO = Pair("UNI_CRO", 3, 2)
EOS_BTC = Pair("EOS_BTC", 7, 2)
YFI_CRO = Pair("YFI_CRO", 2, 4)
XTZ_CRO = Pair("XTZ_CRO", 3, 2)
WBTC_BTC = Pair("WBTC_BTC", 4, 4)
LINK_CRO = Pair("LINK_CRO", 2, 2)
BTC_USDT = Pair("BTC_USDT", 2, 6)
OMG_USDT = Pair("OMG_USDT", 4, 4)
NEO_USDT = Pair("NEO_USDT", 3, 4)
VET_USDT = Pair("VET_USDT", 6, 0)
YFI_USDT = Pair("YFI_USDT", 2, 6)
MANA_BTC = Pair("MANA_BTC", 8, 1)
ATOM_BTC = Pair("ATOM_BTC", 7, 2)
EOS_USDT = Pair("EOS_USDT", 4, 2)
ALGO_BTC = Pair("ALGO_BTC", 8, 2)
KNC_USDT = Pair("KNC_USDT", 3, 3)
AAVE_CRO = Pair("AAVE_CRO", 2, 3)
XLM_USDT = Pair("XLM_USDT", 5, 1)
CELR_CRO = Pair("CELR_CRO", 4, 1)
LINK_BTC = Pair("LINK_BTC", 7, 2)
ENJ_USDT = Pair("ENJ_USDT", 5, 1)
XTZ_USDT = Pair("XTZ_USDT", 4, 2)
QTUM_CRO = Pair("QTUM_CRO", 3, 2)
COMP_CRO = Pair("COMP_CRO", 2, 3)
MKR_USDT = Pair("MKR_USDT", 2, 6)
EGLD_CRO = Pair("EGLD_CRO", 3, 2)
PAXG_CRO = Pair("PAXG_CRO", 2, 4)
DAI_USDT = Pair("DAI_USDT", 4, 3)
LTC_USDT = Pair("LTC_USDT", 2, 5)
ETH_USDT = Pair("ETH_USDT", 2, 5)
BAND_CRO = Pair("BAND_CRO", 3, 2)
XRP_USDT = Pair("XRP_USDT", 5, 1)
BAT_USDT = Pair("BAT_USDT", 4, 2)
CRO_USDC = Pair("CRO_USDC", 4, 3)
UNI_USDT = Pair("UNI_USDT", 4, 4)
BCH_USDT = Pair("BCH_USDT", 2, 5)
MANA_CRO = Pair("MANA_CRO", 3, 2)
CRO_USDT = Pair("CRO_USDT", 4, 3)
ICX_USDT = Pair("ICX_USDT", 4, 2)
ADA_USDT = Pair("ADA_USDT", 5, 1)
ATOM_CRO = Pair("ATOM_CRO", 2, 2)
ALGO_CRO = Pair("ALGO_CRO", 3, 2)
MANA_USDT = Pair("MANA_USDT", 4, 2)
LINK_USDT = Pair("LINK_USDT", 3, 2)
ATOM_USDT = Pair("ATOM_USDT", 3, 2)
COMP_USDT = Pair("COMP_USDT", 2, 5)
PAXG_USDT = Pair("PAXG_USDT", 2, 5)
USDC_USDT = Pair("USDC_USDT", 4, 2)
ALGO_USDT = Pair("ALGO_USDT", 4, 2)
AAVE_USDT = Pair("AAVE_USDT", 3, 4)
CELR_USDT = Pair("CELR_USDT", 5, 1)
EGLD_USDT = Pair("EGLD_USDT", 4, 3)
WBTC_USDT = Pair("WBTC_USDT", 2, 6)
QTUM_USDT = Pair("QTUM_USDT", 4, 4)
BAND_USDT = Pair("BAND_USDT", 4, 2)
REN_CRO = Pair("REN_CRO", 4, 2)
DOT_USDT = Pair("DOT_USDT", 4, 3)
REN_USDT = Pair("REN_USDT", 5, 2)
DOT_CRO = Pair("DOT_CRO", 3, 3)


def all():
    return [
        value for name, value in globals().items()
        if isinstance(value, Pair)
    ]
